#ifndef FEEDURLS_H
#define FEEDURLS_H

#include <QUrl>

const QUrl TRACKS_BASE_FEED("http://api.soundcloud.com/tracks.json?limit=30&filter=public");
const QUrl PLAYLISTS_BASE_FEED("http://api.soundcloud.com/playlists.json?limit=30");
const QUrl USERS_BASE_FEED("http://api.soundcloud.com/users.json?limit=30");
const QUrl GROUPS_BASE_FEED("http://api.soundcloud.com/groups.json?limit=30");

const QUrl UPLOADS_FEED("https://api.soundcloud.com/me/tracks.json?limit=30&filter=public");
const QUrl FAVOURITES_FEED("https://api.soundcloud.com/me/favorites.json?limit=30&filter=public");
const QUrl PLAYLISTS_FEED("https://api.soundcloud.com/me/playlists.json?limit=30");
const QUrl GROUPS_FEED("https://api.soundcloud.com/me/groups.json?limit=30");
const QUrl FOLLOWERS_FEED("https://api.soundcloud.com/me/followers.json?limit=30");
const QUrl FOLLOWINGS_FEED("https://api.soundcloud.com/me/followings.json?limit=30");
const QUrl CONNECTIONS_FEED("https://api.soundcloud.com/me/connections.json?limit=200");
const QUrl ALL_ACTIVITIES_FEED("https://api.soundcloud.com/me/activities/all.json?limit=30");
const QUrl AFFILIATED_TRACKS_ACTIVITIES_FEED("https://api.soundcloud.com/me/activities/tracks/affiliated.json?limit=30");
const QUrl EXCLUSIVE_TRACKS_ACTIVITIES_FEED("https://api.soundcloud.com/me/activities/tracks/exclusive.json?limit=30");
const QUrl OWN_ACVTIVITIES_FEED("https://api.soundcloud.com/me/activities/all/own.json?limit=30");

#endif // FEEDURLS_H
